<?php
namespace FM\Service;

use FM\Factory\SolicitacaoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use FM\Service\FuncionariosHierarqService;
use FM\Service\FileServerService;
use FM\Service\FindService;

class SolicitacaoService {
    
    protected $SolicitacaoFactory;
    protected $FindService;
    protected $environment;
    protected $FuncionariosHierarqService;
    protected $newCode;
    protected $connection;
    protected $FileServerService;
    
    public function __construct (SolicitacaoFactory $SolicitacaoFactory, FindService $FindService, Environment $Environment, FuncionariosHierarqService $FuncionariosHierarqService, NewCode $newCode, EntityManager $entityManager, FileServerService $FileServerService) {
        $this->SolicitacaoFactory           = $SolicitacaoFactory;
        $this->FindService                  = $FindService;
        $this->environment                  = $Environment;
        $this->FuncionariosHierarqService   = $FuncionariosHierarqService;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection(); 
        $this->FileServerService            = $FileServerService;
    }
       
    public function getLocalRequest($params) {
        return $this->SolicitacaoFactory->getLocalRequest($params);
    }


    public function criarSolicitacao($parametros) {
        $this->connection->beginTransaction();

         try {
                $NRORG = $this->environment->getNrOrg();
                $cdoperador = $this->environment->getCdOperador();
                $NRSOLICITACAO = $this->newCode->getCodeByTableName("FCM_SOLICITACAO", $NRORG, 1, 10, true);
                $params = array(
                    "NRSOLICITACAO"  => $NRSOLICITACAO,
                    "NMSOLICITACAO"  => $parametros['NMSOLICITACAO'],
                    "IDSITUACAO"     => $parametros['IDSITUACAO'],
                    "NRLOCALCLIENTE" => $parametros['NRLOCALCLIENTE'],
                    "CDOPERABERTURA" => $cdoperador,
                    "DSSOLICITACAO"  => $parametros['DSSOLICITACAO'],
                    "NRORG"          => $NRORG,
                    "CDOPERINCLUSAO" => $cdoperador,
                    "NRORGINCLUSAO"  => $NRSOLICITACAO,
                    "NRORGULTATU"    => $NRSOLICITACAO,
                    "CDOPERULTATU"   => $cdoperador,
                    

                );
                $this->SolicitacaoFactory->insertNewRequest($params);

                $NRSOLICITACAOHISTORICO = $this->newCode->getCodeByTableName("FCM_SOLICITACAOHISTORICO", $NRORG, 1, 10, true);

                $params = array(
                    "NRSOLICITACAOHISTORICO" => $NRSOLICITACAOHISTORICO,
                    "NRSOLICITACAO"          => $NRSOLICITACAO,
                    "IDSITUACAO"             => 1,
                    "IDTIPOHISTORICO"        => 1,
                    "CDOPERSOLICITANTE"      => $this->environment->getCdOperador(),
                    "DSSOLICITACAO"          => $parametros['DSSOLICITACAO'],
                    "IDSATISFACAOSOLICITA"   => null,
                    "NRORG"                  => $NRORG
                );

                $this->SolicitacaoFactory->insertRequestHistory($params);

                $row = $this->FileServerService->uploadFiles($parametros['IMAGENS'], 'anexosSolicitacoes');

                foreach ($row as $file) {
                    $this->SolicitacaoFactory->insertImg(array(
                        "NRIMGSOLICITACAO" => $this->newCode->getCodeByTableName('FCM_IMGSOLICITACAO', $this->environment->getNrOrg(), 1, 10, true),
                        "NRSOLICITACAO" => $NRSOLICITACAO,
                        "DSCAMINHO" => $file['path'],
                        "NRORG" => $NRORG,
                        "DSTYPE" => $file['type'],
                        "NRSIZE" => $file['size'],
                        "CDOPERINCLUSAO" => $this->environment->getCdOperador()
                    ));
                }

            $this->connection->commit();

        }  catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function showRequest($params) {

        $parametros = array(
            "NRSOLICITACAO"    => $params['NRSOLICITACAO'],
        );

        return $this->SolicitacaoFactory->showRequest($parametros);
    }

    public function getSituationRequest() {

        return $this->SolicitacaoFactory->getSituationRequest();
    }

    public function getNameRequest() {

        return $this->SolicitacaoFactory->getNameRequest();
    }

    public function avaliarSolicitacao($parametros) {
        $this->connection->beginTransaction();

         try {
            $NRORG = $this->environment->getNrOrg();
            $params = array(
                "NRSOLICITACAO"        => $parametros['NRSOLICITACAO'],
                "IDSITUACAO"           => ($parametros['CONDITION']) ? 4 : 1,
                "DSSOLICITACAO"        => $parametros['DSSOLICITACAO']
            );
            $this->SolicitacaoFactory->upRequest($params);
            
            $NRSOLICITACAOHISTORICO = $this->newCode->getCodeByTableName("FCM_SOLICITACAOHISTORICO", $NRORG, 1, 10, true);

            $params = array(
                    "NRSOLICITACAOHISTORICO" => $NRSOLICITACAOHISTORICO,
                    "NRSOLICITACAO"          => $parametros['NRSOLICITACAO'],
                    "IDSITUACAO"             => ($parametros['CONDITION']) ? 4 : 1,
                    "IDTIPOHISTORICO"        => 4,
                    "CDOPERSOLICITANTE"      => $this->environment->getCdOperador(),
                    "DSSOLICITACAO"          => $parametros['DSSOLICITACAO'],
                    "IDSATISFACAOSOLICITA"   => $parametros['IDSATISFACAOSOLICITA'],
                    "NRORG"                  => $NRORG
                );
            $this->SolicitacaoFactory->insertRequestHistory($params);

            $this->connection->commit();

        }  catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    // CODIGO TELA REFATORADA

    public function getSolicitacoes($params) {

        $cdoperador = $this->environment->getCdOperador();
        $listaOperadores = $this->FuncionariosHierarqService->montarHierarquiaOperadores($cdoperador);
        $filter = "";
        
        if ($params['TIPO'] == "2") {

            if(isset($params['NRLOCALCLIENTE'])) {
                $local = $this->FindService->formatarArray($params['NRLOCALCLIENTE']);
                $filter =  $filter." AND S.NRLOCALCLIENTE IN (".$local.")";
            }

            if(isset($params['DTHORAAGEND'])) {
                $filter = $filter." AND DTSOLICITACAO BETWEEN'".$params['DTHORAAGEND'][0]."' AND '".$params['DTHORAAGEND'][1]."'";
            }  

            if(isset($params['IDSITUACAO'])) {
                $situacao = $this->FindService->formatarArray($params['IDSITUACAO']);
                $filter = $filter." AND IDSITUACAO IN (".$situacao.")";
            } 

             if(isset($params['NRSOLICITACAO'])) {
                $solicitacao = $this->FindService->formatarArray($params['NRSOLICITACAO']);
                $filter = $filter." AND S.NRSOLICITACAO IN (".$solicitacao.")";
            }
        }
    
        return $this->SolicitacaoFactory->getSolicitacoes($listaOperadores, $filter);
    }

    public function getFotosSolicitacao($params) {
        return $this->SolicitacaoFactory->getFotosSolicitacao($params);
    }
}
?>